=======================
The ``atelier`` package
=======================




`atelier` is a collection of tools for managing and maintaining Python software
projects.

It contains a minimalistic project management and a library of `invoke
<https://www.pyinvoke.org/>`_ commands.

- Source code: https://gitlab.com/lino-framework/atelier
- Documentation: https://lino-framework.gitlab.io/atelier


